==> ametys-plugin-odf-4.8.16.20251101-0053-b333-SNAPSHOT.jar: org/ametys/odf/program/Program.java <==
/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.program;

import java.util.Collections;
import java.util.List;

import javax.jcr.Node;

import org.ametys.cms.data.ContentDataHelper;
import org.ametys.odf.cdmfr.CDMFRTagsConstants;
import org.ametys.runtime.model.exception.UndefinedItemPathException;

/**
 * This class represent the root element of a program
 */
public class Program extends AbstractProgram<ProgramFactory>
{
    /**
     * Constructor.
     * @param node the JCR Node backing this Content.
     * @param parentPath the parent path in the Ametys hierarchy.
     * @param factory the corresponding {@link ProgramFactory}.
     */
    public Program(Node node, String parentPath, ProgramFactory factory)
    {
        super(node, parentPath, factory);
    }
    
    @Override
    public List<ProgramPart> getProgramPartParents()
    {
        return Collections.EMPTY_LIST;
    }
    
    // --------------------------------------------------------------------------------------//
    // CDMfr
    // --------------------------------------------------------------------------------------//
    @Override
    public String getCDMTagName()
    {
        return CDMFRTagsConstants.TAG_PROGRAM;
    }
    
    /**
     * Get the degree
     * @return the degree or null
     */
    public String getDegree()
    {
        try
        {
            return ContentDataHelper.getContentIdFromContentData(this, DEGREE);
        }
        catch (UndefinedItemPathException e)
        {
            return null; // this attribute is not part of model
        }
    }
}

==> ametys-plugin-odf-4.9.7.20260205-0017-b147-SNAPSHOT.jar: org/ametys/odf/program/Program.java <==
/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.program;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

import javax.jcr.Node;

import org.ametys.cms.data.ContentDataHelper;
import org.ametys.cms.data.ContentValue;
import org.ametys.cms.repository.Content;
import org.ametys.odf.cdmfr.CDMFRTagsConstants;
import org.ametys.runtime.model.exception.UndefinedItemPathException;

/**
 * This class represent the root element of a program
 */
public class Program extends AbstractProgram<ProgramFactory>
{
    /** Constants for attribute 'skills' */
    public static final String SKILLS = "skills";
    /** Constants for attribute 'transversalSkills' */
    public static final String TRANSVERSAL_SKILLS = "transversalSkills";
    /** Constants for attribute 'blockingMicroSkills' */
    public static final String BLOCKING_SKILLS = "blockingMicroSkills";
    
    /**
     * Constructor.
     * @param node the JCR Node backing this Content.
     * @param parentPath the parent path in the Ametys hierarchy.
     * @param factory the corresponding {@link ProgramFactory}.
     */
    public Program(Node node, String parentPath, ProgramFactory factory)
    {
        super(node, parentPath, factory);
    }
    
    @Override
    public List<ProgramPart> getProgramPartParents()
    {
        return Collections.EMPTY_LIST;
    }
    
    // --------------------------------------------------------------------------------------//
    // CDMfr
    // --------------------------------------------------------------------------------------//
    @Override
    public String getCDMTagName()
    {
        return CDMFRTagsConstants.TAG_PROGRAM;
    }
    
    /**
     * Get the degree
     * @return the degree or null
     */
    public String getDegree()
    {
        try
        {
            return ContentDataHelper.getContentIdFromContentData(this, DEGREE);
        }
        catch (UndefinedItemPathException e)
        {
            return null; // this attribute is not part of model
        }
    }
    
    /**
     * Get the acquired skills
     * @return the acquired skills
     */
    public List<Content> getSkills()
    {
        try
        {
            return Arrays.stream(getValue(SKILLS, false, new ContentValue[0]))
                .map(ContentValue::getContentIfExists)
                .flatMap(Optional::stream)
                .collect(Collectors.toList());
        }
        catch (UndefinedItemPathException e)
        {
            return List.of(); // this attribute is not part of model, skills are not enabled
        }
    }
    
    /**
    * Get the acquired transversal skills
    * @return the acquired transversal skills
    */
    public List<Content> getTransversalSkills()
    {
        try
        {
            return Arrays.stream(getValue(TRANSVERSAL_SKILLS, false, new ContentValue[0]))
                .map(ContentValue::getContentIfExists)
                .flatMap(Optional::stream)
                .collect(Collectors.toList());
        }
        catch (UndefinedItemPathException e)
        {
            return List.of(); // this attribute is not part of model, skills are not enabled
        }
    }
}
